Crate covey

Crate covey 

Structs

Host
Main public API for interacting with covey.
Input
The main text input contents and selection.
List
A list of results to show provided by a plugin.
ListItem
A single result provided by a plugin.
ListItemId
A list item without rendering details (description, etc).
Plugin
A ref-counted reference to a plugin instance.

Enums

ListStyle
The style to display the list provided by a plugin.
ResolvedIcon
Icon with named system icons resolved to a file path.

Statics

CONFIG_DIR
CONFIG_PATH
DATA_DIR
PLUGINS_DIR

Traits

Frontend
A controller for the UI.