Structs
- Host
- Main public API for interacting with covey.
- Input
- The main text input contents and selection.
- List
- A list of results to show provided by a plugin.
- List
Item - A single result provided by a plugin.
- List
Item Id - A list item without rendering details (description, etc).
- Plugin
- A ref-counted reference to a plugin instance.
Enums
- List
Style - The style to display the list provided by a plugin.
- Resolved
Icon - Icon with named system icons resolved to a file path.
Statics
Traits
- Frontend
- A controller for the UI.